/* outline.h - declarations to populate a ctree from an xml file
   Copyright (C) 1999, 2000 Peter Teichman

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
   USA.  */

#ifndef __OUTLINE_H__
#define __OUTLINE_H__

#include <glib.h>

gpointer outline_load_xml (gchar *filename, GNode **root);
void     outline_save_xml (gchar *filename, GNode *root);

#endif /* __OUTLINE_H__ defined */
